@@ -25,14 +25,14 @@ class DeleteJobTemplatesRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'DeleteJobTemplates')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Templates(self):
+	def get_Templates(self): # String
 		return self.get_query_params().get('Templates')
 
-	def set_Templates(self,Templates):
-		self.add_query_param('Templates',Templates)
\ No newline at end of file
+	def set_Templates(self, Templates):  # String
+		self.add_query_param('Templates', Templates)
