@@ -25,62 +25,54 @@ class GetAccountingReportRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'GetAccountingReport')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ReportType(self):
+	def get_ReportType(self): # String
 		return self.get_query_params().get('ReportType')
 
-	def set_ReportType(self,ReportType):
-		self.add_query_param('ReportType',ReportType)
-
-	def get_EndTime(self):
+	def set_ReportType(self, ReportType):  # String
+		self.add_query_param('ReportType', ReportType)
+	def get_EndTime(self): # Integer
 		return self.get_query_params().get('EndTime')
 
-	def set_EndTime(self,EndTime):
-		self.add_query_param('EndTime',EndTime)
-
-	def get_FilterValue(self):
+	def set_EndTime(self, EndTime):  # Integer
+		self.add_query_param('EndTime', EndTime)
+	def get_FilterValue(self): # String
 		return self.get_query_params().get('FilterValue')
 
-	def set_FilterValue(self,FilterValue):
-		self.add_query_param('FilterValue',FilterValue)
-
-	def get_Dim(self):
+	def set_FilterValue(self, FilterValue):  # String
+		self.add_query_param('FilterValue', FilterValue)
+	def get_Dim(self): # String
 		return self.get_query_params().get('Dim')
 
-	def set_Dim(self,Dim):
-		self.add_query_param('Dim',Dim)
-
-	def get_ClusterId(self):
+	def set_Dim(self, Dim):  # String
+		self.add_query_param('Dim', Dim)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_StartTime(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_StartTime(self): # Integer
 		return self.get_query_params().get('StartTime')
 
-	def set_StartTime(self,StartTime):
-		self.add_query_param('StartTime',StartTime)
-
-	def get_PageNumber(self):
+	def set_StartTime(self, StartTime):  # Integer
+		self.add_query_param('StartTime', StartTime)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_JobId(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_JobId(self): # String
 		return self.get_query_params().get('JobId')
 
-	def set_JobId(self,JobId):
-		self.add_query_param('JobId',JobId)
-
-	def get_PageSize(self):
+	def set_JobId(self, JobId):  # String
+		self.add_query_param('JobId', JobId)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
\ No newline at end of file
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
