@@ -25,40 +25,36 @@ class InvokeShellCommandRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'InvokeShellCommand')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Instances(self):
+	def get_Instances(self): # RepeatList
 		return self.get_query_params().get('Instance')
 
-	def set_Instances(self, Instances):
-		for depth1 in range(len(Instances)):
-			if Instances[depth1].get('Id') is not None:
-				self.add_query_param('Instance.' + str(depth1 + 1) + '.Id', Instances[depth1].get('Id'))
-
-	def get_WorkingDir(self):
+	def set_Instances(self, Instance):  # RepeatList
+		for depth1 in range(len(Instance)):
+			if Instance[depth1].get('Id') is not None:
+				self.add_query_param('Instance.' + str(depth1 + 1) + '.Id', Instance[depth1].get('Id'))
+	def get_WorkingDir(self): # String
 		return self.get_query_params().get('WorkingDir')
 
-	def set_WorkingDir(self,WorkingDir):
-		self.add_query_param('WorkingDir',WorkingDir)
-
-	def get_ClusterId(self):
+	def set_WorkingDir(self, WorkingDir):  # String
+		self.add_query_param('WorkingDir', WorkingDir)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_Command(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_Command(self): # String
 		return self.get_query_params().get('Command')
 
-	def set_Command(self,Command):
-		self.add_query_param('Command',Command)
-
-	def get_Timeout(self):
+	def set_Command(self, Command):  # String
+		self.add_query_param('Command', Command)
+	def get_Timeout(self): # Integer
 		return self.get_query_params().get('Timeout')
 
-	def set_Timeout(self,Timeout):
-		self.add_query_param('Timeout',Timeout)
\ No newline at end of file
+	def set_Timeout(self, Timeout):  # Integer
+		self.add_query_param('Timeout', Timeout)
