@@ -25,46 +25,41 @@ class ListInvocationResultsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'ListInvocationResults')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Instances(self):
+	def get_Instances(self): # RepeatList
 		return self.get_query_params().get('Instance')
 
-	def set_Instances(self, Instances):
-		for depth1 in range(len(Instances)):
-			if Instances[depth1].get('Id') is not None:
-				self.add_query_param('Instance.' + str(depth1 + 1) + '.Id', Instances[depth1].get('Id'))
-
-	def get_ClusterId(self):
+	def set_Instances(self, Instance):  # RepeatList
+		for depth1 in range(len(Instance)):
+			if Instance[depth1].get('Id') is not None:
+				self.add_query_param('Instance.' + str(depth1 + 1) + '.Id', Instance[depth1].get('Id'))
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_CommandId(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_CommandId(self): # String
 		return self.get_query_params().get('CommandId')
 
-	def set_CommandId(self,CommandId):
-		self.add_query_param('CommandId',CommandId)
-
-	def get_PageNumber(self):
+	def set_CommandId(self, CommandId):  # String
+		self.add_query_param('CommandId', CommandId)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_InvokeRecordStatus(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_InvokeRecordStatus(self): # String
 		return self.get_query_params().get('InvokeRecordStatus')
 
-	def set_InvokeRecordStatus(self,InvokeRecordStatus):
-		self.add_query_param('InvokeRecordStatus',InvokeRecordStatus)
-
-	def get_PageSize(self):
+	def set_InvokeRecordStatus(self, InvokeRecordStatus):  # String
+		self.add_query_param('InvokeRecordStatus', InvokeRecordStatus)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
\ No newline at end of file
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
